==> mutual_credit-5.0.1.tar.gz: mutual_credit/src/Entity/ViewBuilder/WalletViewBuilder.php <==
<?php

namespace Drupal\mcapi\Entity\ViewBuilder;

use Drupal\mcapi\Entity\Currency;
use Drupal\mcapi\Entity\CurrencyInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;

/**
 * Render controller for wallets.
 */
class WalletViewBuilder extends EntityViewBuilder {

  /**
   * {@inheritdoc}
   */
  protected function getBuildDefaults(EntityInterface $entity, $view_mode) {
    $build = parent::getBuildDefaults($entity, $view_mode);
    // Add the css.
    $build['#attached'] = ['library' => ['mcapi/mcapi.wallets']];
    return $build;
  }



  public function buildComponents(&$build, array $entities, array $displays, $view_mode) {
    $display = $displays['mcapi_wallet'];
    $unused = (bool)\Drupal::config('mcapi.settings')->get('render_unused');
    foreach ($entities as $id => $wallet) {
      $all_stats = $wallet->getAllStats($unused);
      $currencies = Currency::loadMultiple(array_keys($all_stats));
      if ($options = $display->getComponent('balance_bars')) {
        foreach ($currencies as $curr_id => $currency) {
          $build[$id]['balance_bars_'.$curr_id] = [
            '#title' => t('Wallet: %name', ['%name' => $wallet->label()]),
            '#theme' => 'wallet_balance_bars',
            '#wallet' => $wallet,
            '#currency' => $currency,
            '#attributes' => ['class' => ['component', 'balance_bars']],
            '#weight' => $options['weight'],
          ];
        }
      }
      if ($options = $display->getComponent('histories')) {
        foreach ($currencies as $curr_id => $currency) {
          $build[$id]['histories_'.$curr_id] = [
          // Only used if we add theme wrappers.
            '#title' => t('Balance history'),
            '#type' => 'balance_histories',
            '#wallet' => $wallet,
            '#currency' => $currency,
            '#attributes' => ['class' => ['component', 'histories']],
            '#weight' => $options['weight'],
            '#width' => 300,
          ];
        }
      }
      if ($options = $display->getComponent('stats')) {
        $build[$id]['stats'] = [
          '#title' => t('Wallet: %name', ['%name' => $wallet->label()]),
          '#theme' => 'wallet_stats',
          '#wallet' => $wallet,
          '#attributes' => ['class' => ['component', 'stats']],
          '#weight' => $options['weight'],
        ];
      }
      if ($options = $display->getComponent('balances')) {
        $delimiter = \Drupal::config('mcapi.settings')->get('worths_delimiter');
        $balances = [];
        foreach ($all_stats as $curr_id => $stats) {
          $balances[] = $currencies[$curr_id]->format($stats->balance, CurrencyInterface::DISPLAY_NORMAL, TRUE);
        }
        $build[$id]['balances'] = [
          '#type' => 'item',
          '#title' => t('Balance'),
          '#markup'=> Markup::Create(implode($delimiter, $balances))
        ];
      }
      if ($options = $display->getComponent('link_transactions')) {
        $tx_view_name = \Drupal::config('mcapi.settings')->get('user_transaction_view') == 'inex' ?
          'income_expenditure' :
          'wallet_transactions';
        $build[$id]['link_transactions'] = [
          '#type' => 'link',
          '#title' => t('View transactions'),
          '#url' => Url::fromRoute(
            "view.$tx_view_name.wallet_page",
            ['mcapi_wallet' => $wallet->id()]
          ),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $options['weight'],
        ];
      }
      if ($options = $display->getComponent('viz_balance')) {
        foreach ($all_stats as $curr_id => $stats){
          $build[$id]['trades'] = [
            '#theme' => 'viz_balance',
            '#gross_in' => $stats->gross_in,
            '#gross_out' => $stats->gross_out,
            '#curr_id' => $curr_id,
            '#weight' => $options['weight'],
          ];
        }
      }
      if ($options = $display->getComponent('canonical_link')) {
        $build[$id]['canonical_link'] = [
          '#type' => 'link',
          '#title' => t('more...'),
          '#url' => Url::fromRoute('entity.mcapi_wallet.canonical', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $options['weight'],
        ];
      }
    //  Group all the above by currency
    //  foreach ($currencies as $currency) {
    //    $build[$id][$currency->id]+= [
    //      '#type' => 'fieldset',
    //      '#title' => $currency->name,
    //    ];
    //  }
    }
  }


}

==> mutual_credit-5.0.3.tar.gz: mutual_credit/src/Entity/ViewBuilder/WalletViewBuilder.php <==
<?php

namespace Drupal\mcapi\Entity\ViewBuilder;

use Drupal\mcapi\Entity\Currency;
use Drupal\mcapi\Entity\CurrencyInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;

/**
 * Render controller for wallets.
 */
class WalletViewBuilder extends EntityViewBuilder {

  /**
   * {@inheritdoc}
   */
  protected function getBuildDefaults(EntityInterface $entity, $view_mode) {
    $build = parent::getBuildDefaults($entity, $view_mode);
    // Add the css.
    $build['#attached'] = ['library' => ['mcapi/mcapi.wallets']];
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function buildComponents(&$build, array $entities, array $displays, $view_mode) {
    $display = $displays['mcapi_wallet'];
    $unused = (bool)\Drupal::config('mcapi.settings')->get('render_unused');
    foreach ($entities as $id => $wallet) {
      if ($view_mode <> 'full') {
        $build[$id]['title']['#markup'] = '<label>'.t("Wallet: @label", ['@label' => $wallet->label()]).'</label>';
      }
      $all_stats = $wallet->getAllStats($unused);
      $currencies = Currency::loadMultiple(array_keys($all_stats));
      if ($options = $display->getComponent('balance_bars')) {
        foreach ($currencies as $curr_id => $currency) {
          $build[$id]['balance_bars_'.$curr_id] = [
            '#title' => $this->t('Wallet: %name', ['%name' => $wallet->label()]),
            '#theme' => 'wallet_balance_bars',
            '#wallet' => $wallet,
            '#currency' => $currency,
            '#attributes' => ['class' => ['component', 'balance_bars']],
            '#weight' => $options['weight'],
          ];
        }
      }
      if ($options = $display->getComponent('histories')) {
        foreach ($currencies as $curr_id => $currency) {
          $build[$id]['histories_'.$curr_id] = [
          // Only used if we add theme wrappers.
            '#title' => $this->t('Balance history'),
            '#type' => 'balance_histories',
            '#wallet' => $wallet,
            '#currency' => $currency,
            '#attributes' => ['class' => ['component', 'histories']],
            '#weight' => $options['weight'],
            '#width' => 300,
          ];
        }
      }
      if ($options = $display->getComponent('stats')) {
        $build[$id]['stats'] = [
          '#title' => $this->t('Wallet: %name', ['%name' => $wallet->label()]),
          '#theme' => 'wallet_stats',
          '#wallet' => $wallet,
          '#attributes' => ['class' => ['component', 'stats']],
          '#weight' => $options['weight'],
        ];
      }
      if ($options = $display->getComponent('balances')) {
        $delimiter = \Drupal::config('mcapi.settings')->get('worths_delimiter');
        $balances = [];
        foreach ($all_stats as $curr_id => $stats) {
          $balances[] = $currencies[$curr_id]->format($stats->balance, CurrencyInterface::DISPLAY_NORMAL, TRUE);
        }
        $build[$id]['balances'] = [
          '#type' => 'item',
          '#title' => t('Balances'),
          '#markup'=> Markup::Create(implode($delimiter, $balances))
        ];
      }
      if ($options = $display->getComponent('viz_balance')) {
        foreach ($all_stats as $curr_id => $stats){
          $build[$id]['trades'] = [
            '#theme' => 'viz_balance',
            '#gross_in' => $stats->gross_in,
            '#gross_out' => $stats->gross_out,
            '#curr_id' => $curr_id,
            '#weight' => $options['weight'],
          ];
        }
      }
      if ($options = $display->getComponent('link_transactions')) {
        $tx_view_name = \Drupal::config('mcapi.settings')->get('user_transaction_view') == 'inex' ?
          'income_expenditure' :
          'wallet_transactions';
        $build[$id]['link_transactions'] = [
          '#type' => 'link',
          '#title' => $this->t('View transactions'),
          '#url' => Url::fromRoute("view.$tx_view_name.wallet_page", ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $options['weight'],
        ];
      }
      if ($options = $display->getComponent('link_canonical')) {
        $build[$id]['link_canonical'] = [
          '#type' => 'link',
          '#title' => "<br />" . $this->t('details...'),
          '#url' => Url::fromRoute('entity.mcapi_wallet.canonical', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $options['weight'],
        ];
      }
    //  Group all the above by currency
    //  foreach ($currencies as $currency) {
    //    $build[$id][$currency->id]+= [
    //      '#type' => 'fieldset',
    //      '#title' => $currency->name,
    //    ];
    //  }
    }
  }

}
